#
# spec file for package libmfx-gen
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global sover 1_2
Name:           libmfx-gen
%define lname   libmfx-gen%{sover}
Version:        22.6.1
Release:        150500.1.15
Summary:        Intel oneVPL GPU Runtime
License:        MIT
Group:          Development/Languages/C and C++
URL:            https://github.com/oneapi-src/oneVPL-intel-gpu
Source0:        intel-onevpl-%{version}.tar.gz
Source1:        supplements.inc
Source2:        generate-supplements.sh
BuildRequires:  cmake
BuildRequires:  gcc-c++
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(libva)
ExclusiveArch:  x86_64

%description
Intel oneVPL GPU Runtime is a Runtime implementation of oneVPL
API for Intel Gen GPUs: Runtime provides access to
hardware-accelerated video decode, encode and filtering.

%package -n %lname
Summary:        Intel oneVPL GPU Runtime
Group:          System/Libraries
%include %{S:1}

%description -n %lname
Intel oneVPL GPU Runtime is a Runtime implementation of oneVPL
API for Intel Gen GPUs: Runtime provides access to
hardware-accelerated video decode, encode and filtering.

%package devel
Summary:        Development files for Intel oneVPL GPU Runtime
Group:          Development/Languages/C and C++
Requires:       %lname = %version

%description devel
This package contains the development headers and pkgconfig files for
the Intel oneVPL GPU Runtime.

%prep
%autosetup -p1 -n oneVPL-intel-gpu-intel-onevpl-%{version}

%build
mkdir -p build
pushd build
cmake -DCMAKE_INSTALL_PREFIX="%{_prefix}" ..
make %{?_smp_mflags}
popd

%install
pushd build
%make_install
popd

%post -n %lname -p /sbin/ldconfig

%postun -n %lname -p /sbin/ldconfig

%files
%doc README.md

%files -n %lname
%license LICENSE
%{_libdir}/libmfx-gen.so.1*
%dir %{_libdir}/libmfx-gen
%{_libdir}/libmfx-gen/enctools.so

%files devel
%{_libdir}/libmfx-gen.so
%{_libdir}/pkgconfig/libmfx-gen.pc

%changelog
* Mon Nov  7 2022 sndirsch@suse.com
- needed for jira#PED-1174 (Video decoding/encoding support
  (VA-API, ...) for Intel GPUs is outside of Mesa)
* Thu Nov  3 2022 sndirsch@suse.com
- Update to version 22.6.1
  * latest bugfix release
- supersedes u_libva-2.16.0.patch
* Fri Sep 30 2022 sndirsch@suse.com
- u_libva-2.16.0.patch
  * fixes build against libva 2.16.0
  * culprit: https://github.com/intel/libva/commit/8682f9e30f2fabf2ccc6f7609db035ed1af44703
* Mon Jul 11 2022 sndirsch@suse.com
- Update to version 22.4.4
  * Decode:
    + Fix VC1 Decode assertion failure when frame type is NONE_PICTURE
    + Fix AV1 Decode hang issue in error clips that OBU info size is
    larger than bitstream size.
  * part of Intel oneVPL GPU Runtime 2022Q2 Release 22.4.4
- supersedes U_Removed-proprietary-mentions-from-file-headers-1023.patch
- filelist: added {_libdir}/libmfx-gen/enctools.so
* Tue Oct 12 2021 sndirsch@suse.com
- U_Removed-proprietary-mentions-from-file-headers-1023.patch
  * upstream patch, which replaces proprietary Intel license with
    OpenSource MIT license (github issue#183)
- this addresses the legal issues we had with checkin for sle15-sp4/
  Leap 15.4
* Mon Oct  4 2021 sndirsch@suse.com
- fixed JIRA number in the initial changelog
* Wed Sep 29 2021 sndirsch@suse.com
- Update to version 21.3.4
  * [vp9d] fix unsigned qindex issue for vp9 segmentation case (#569)
  * [EncTools] Add closed GOP support for LPLA (#585)
  * [Jpegd] Modify the resolution judgment condition of the current jpeg (#522)
  * [LPLA] Zero sao_enabled flag for LPLA (#538)
  * [AVCe] Fix typos in NumRefActive (#595)
  * Refactor cmake (#466)
  * Refactor root cmake (#467)
  * cm: set correct timeout (#604)
  * [EncTools] Make IDRDist U32 (#596)
  * Refine for commit 2bc6fab
  * Revert "[Jpegd] Modify the resolution judgment condition of the current jpeg (#522)" (#619)
  * Revert "Fix vpp_reset and mfxvideovpp_query beh test (#573)" (#620)
  * [Jpegd] modify the resolution judgment condition of the current jpeg (#623)
  * Fix exception handling issue (#581)
  * [VPP] Enabled Denoise2(as known as HVS) on Linux (#592)
  * core: removed VPL / MSDK1.x RT switch (#603)
  * umc allocator adapter: decoders will not accept locked surface (#629)
  * [MPEG2d] fix bug when the bitstream end with slice start code (#598)
  * [VPP] Fix increasing num of input channels doesn't work (#647)
  * CM: refactored CM integration (#413)
  * Refine for commit 8221d4a
  * [UMC] remove vm_shared_object file (#492)
  * Revert "CM: refactored CM integration" (#654)
  * Revert "umc allocator adapter: decoders will not accept locked surface (#629)" (#655)
  * umc allocator adapter: decoders will not accept locked surface (#3114) (#657)
  * [Jpeg]modify color range on Linux (#653)
  * Fixes. Code review 1 (#640)
  * Revert "[Jpegd] modify the resolution judgment condition of the current jpeg (#623)" (#663)
  * [Encode] MFX_EXT_BRC_ENABLE rename to MFX_ENABLE_EXT_BRC (#627)
  * vaapi core: clean up unused interface (#667)
  * [VPP] Add surface support(in CPU memory) for HVS denoise (#601)
  * [SCD] Fix sys mem allocate issue (#690)
  * Disable SCD (#708)
  * [core] Move CloneSession to RT (#695)
  * [Encode] Support main10 still picture profile (#713)
  * Refine for commit 0a3c8e7
  * [Decode]Enable AVC CSC via sfc pipeline (#712)
  * [Decode]Enable VP9 CSC via sfc pipeline (#722)
  * Removed multiple calls vaGetConfigAttributes (#716)
  * Remove assert in ConvertRateControlMFX2VAAPI (#717)
* Thu Sep 23 2021 sndirsch@suse.com
- created package libmfx-gen (jira#SLE/SLE-19361)
  Intel oneVPL GPU Runtime is a Runtime implementation of oneVPL
  API for Intel Gen GPUs: Runtime provides access to
  hardware-accelerated video decode, encode and filtering.
